#
# $Id: Signature.pm 17 2012-09-10 12:35:30Z gomor $
#
package Net::SinFP3::Plugin::Signature;
use strict;
use warnings;

our $VERSION = '1.00';

1;

__END__

=head1 NAME

Net::SinFP3::Plugin::Signature - plugin to handle signatures from SinFP3 database

=head1 DESCRIPTION

Go to http://www.networecon.com/tools/sinfp/ to know more.

=head1 AUTHOR

Patrice E<lt>GomoRE<gt> Auffret

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2011-2012, Patrice E<lt>GomoRE<gt> Auffret

You may distribute this module under the terms of the Artistic license.
See LICENSE.Artistic file in the source distribution archive.

=cut
